gentle.generators — gentle 0.4.0

# gentle.generators

Generic generator routines

Classes

`AbstractGenerator`(srcdir) | Generic class for metadata generators.

Modules

`gentle.generators.autoconf` | Metadata XML generator for GNU Autoconf.
`gentle.generators.bower` | Metadata XML generator for Bower.
`gentle.generators.cargo` | Metadata XML generator for Cargo.
`gentle.generators.composer` | Metadata XML generator for PHP Composer.
`gentle.generators.doap` | Metadata XML generator for DOAP.
`gentle.generators.hpack` | Metadata XML generator for Haskell Hpack.
`gentle.generators.npm` | Metadata XML generator for Node.js npm.
`gentle.generators.nuspec` | Metadata XML generator for NuGet.
`gentle.generators.pear` | Metadata XML generator for PHP PEAR and PECL.
`gentle.generators.pom` | Metadata XML generator for Apache Maven POM.
`gentle.generators.pubspec` | Metadata XML generator for Dart Pub.
`gentle.generators.python` | Common data for Python generators
`gentle.generators.shards` | Metadata XML generator for Crystal Shards.